#!/bin/bash
#Salome Database creation

SCRIPT_NAME=`basename $0 .sh`
SCRIPT_DIR="`dirname $0`"
LOG_FILE="$SCRIPT_DIR/$SCRIPT_NAME.log"
BDD_DIR="$SCRIPT_DIR/../bdd_model"
CFG_DIR="$SCRIPT_DIR/../cfg"


out() {
        echo "`date +'%Y-%m-%d %H:%M:%S'`: $*" | tee -a $LOG_FILE
}

usage(){
        echo "Usage ./$SCRIPT_NAME.sh [-v] [-h host_ip_address] [-n host_port] [-u user] [-p password] [-d database]"
	echo "Options:"
	echo "-h host_ip_address	:	mysql database host server ip address (default localhost)"
	echo "-n host_port		:	mysql database host server port number (default 3306)"
	echo "-u user			:	mysql database admin user login (default root)"
	echo "-p password		:	mysql database admin user password"
	echo "-d database		:	mysql database name (default root)"
}

# Handle options
vflag=
USER=root
PWD=
BDD=salome
HOST=`hostname -i | sed 's:127.* ::;s: .*$::'`
PORT=3306
while getopts 'vu:p:h:n:d:' OPTION
do
  case $OPTION in
  v)    vflag="-v"
                ;;
  u)    USER=$OPTARG
                ;;
  p)    PWD="-p$OPTARG"
	S_PWD=$OPTARG
                ;;
  h)    HOST=$OPTARG
                ;;
  n)    PORT=$OPTARG
                ;;
  d)    BDD=$OPTARG
                ;;
  ?)    usage
        exit 2
        ;;
  esac
done
shift $(($OPTIND - 1))

if [ ! -z "$vflag" ]; then
        set -xv
fi

out "$BDD Database creation"
mysql -u $USER $PWD mysql -e "create database $BDD" 2>> $LOG_FILE
RES=$?
if [ $RES -ne 0 ]; then
	out "$BDD Database creation failed: error n°$RES. Aborting install. Check log file"
	exit $RES
fi
out "$BDD Database tables creation"
mysql -u $USER $PWD $BDD < $BDD_DIR/create_salome_bdd_withoutref.sql 2>> $LOG_FILE
RES=$?
if [ $RES -ne 0 ]; then
	out "$BDD Database tables creation failed: error n°$RES. Aborting install. Check log file"
	exit $RES
fi
out "Database configuration access setting"
sed -r -e 's:<USER/>:'"$USER"':;s:<PWD/>:'"$S_PWD"':;s:<BDD/>:'"$BDD"':;s:<HOST/>:'"$HOST"':;s:<PORT/>:'"$PORT"':' $SCRIPT_DIR/DB_Connexion.properties > $CFG_DIR/DB_Connexion.properties 2>> $LOG_FILE
RES=$?
if [ $RES -ne 0 ]; then
	out "$BDD Database configuration access setting failed. Aborting install. Check log file"
	exit $RES
fi

out "Salome database successfully installed"
